@@ -1,6 +1,6 @@
 package Catalyst::Action::RenderView::ErrorHandler::Action;
-BEGIN {
-  $Catalyst::Action::RenderView::ErrorHandler::Action::VERSION = '0.100161';
+{
+  $Catalyst::Action::RenderView::ErrorHandler::Action::VERSION = '0.100162';
 }
 #ABSTRACT: A Role for any actions that want to react to errors.
 
@@ -24,12 +24,12 @@ Catalyst::Action::RenderView::ErrorHandler::Action - A Role for any actions that
 
 =head1 VERSION
 
-version 0.100161
+version 0.100162
 
 =head1 SYNOPSIS
 
     use Moose;
-    
+
     with 'Catalyst::Action::RenderView::ErrorHandler::Action';
 
 =head1 DESCRIPTION
@@ -50,8 +50,8 @@ This is the ID which you can refer to when defining handlers
 
 This method need to be implemented by consuming classes.
 
-It will be called with $context, and thus makes it possible
-to access $context->errors for instance, include them in an
+It will be called with C<$context>, and thus makes it possible
+to access C<< $context->errors >> for instance, include them in an
 email or whatnot
 
 =head2 INHERITED METHODS
